pub trait Container:
Send
+ Sync
+ 'static {
// Required method
fn init<'life0, 'async_trait>(
&'life0 self,
request: Request<ContainerInitRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ContainerInitResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Generated trait containing gRPC methods that should be implemented for use with ContainerServer.
Required Methods
Sourcefn init<'life0, 'async_trait>(
&'life0 self,
request: Request<ContainerInitRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ContainerInitResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn init<'life0, 'async_trait>(
&'life0 self,
request: Request<ContainerInitRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ContainerInitResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Initialize OCI container (called after GuestInit) Prepares rootfs, then starts the container with the provided configuration