Files

Trait Files 

pub trait Files:
    Send
    + Sync
    + 'static {
    type DownloadStream: Stream<Item = Result<DownloadChunk, Status>> + Send + 'static;

    // Required methods
    fn upload<'life0, 'async_trait>(
        &'life0 self,
        request: Request<Streaming<UploadChunk>>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<UploadResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn download<'life0, 'async_trait>(
        &'life0 self,
        request: Request<DownloadRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DownloadStream>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Generated trait containing gRPC methods that should be implemented for use with FilesServer.

Required Associated Types

type DownloadStream: Stream<Item = Result<DownloadChunk, Status>> + Send + 'static

Server streaming response type for the Download method.

Required Methods

fn upload<'life0, 'async_trait>( &'life0 self, request: Request<Streaming<UploadChunk>>, ) -> Pin<Box<dyn Future<Output = Result<Response<UploadResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Upload a tar archive and extract it into the container rootfs at dest_path

fn download<'life0, 'async_trait>( &'life0 self, request: Request<DownloadRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DownloadStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Download a path from the container rootfs as a tar archive

Implementors