pub struct BlockDeviceSource {
pub device: String,
pub filesystem: i32,
pub need_format: bool,
pub need_resize: bool,
}Expand description
Block device volume source
Controls how block devices are mounted in the guest:
- filesystem: Target filesystem type (only EXT4 supported for resize)
- need_format: If true, format device before mounting (use for fresh disks)
- need_resize: If true, resize filesystem after mounting to fill available space (use when QCOW2 virtual size > filesystem size)
Fields
device: Stringdevice path (e.g., “/dev/vda”)
filesystem: i32target filesystem type (e.g., EXT4)
need_format: boolif true, format device with filesystem before mount
need_resize: boolif true, run resize2fs after mount to fill disk
Implementations
Sourceimpl BlockDeviceSource
impl BlockDeviceSource
Sourcepub fn filesystem(&self) -> Filesystem
pub fn filesystem(&self) -> Filesystem
Returns the enum value of filesystem, or the default if the field is set to an invalid enum value.
Sourcepub fn set_filesystem(&mut self, value: Filesystem)
pub fn set_filesystem(&mut self, value: Filesystem)
Sets filesystem to the provided enum value.