Module tar

Module tar 

Tar archive pack/unpack for host↔guest file transfer.

Both host (boxlite) and guest agent share this module to avoid duplicating tar building/extraction logic.

Structs

PackContext
Controls how a source path is packed into a tar archive.
UnpackContext
Controls how a tar archive is unpacked to a destination.

Functions

pack
Pack src (file or directory) into a tar archive at tar_path.
unpack
Unpack a tar archive to dest.