Tar archive pack/unpack for host↔guest file transfer.
Both host (boxlite) and guest agent share this module to avoid duplicating tar building/extraction logic.
Structs
- Pack
Context - Controls how a source path is packed into a tar archive.
- Unpack
Context - Controls how a tar archive is unpacked to a destination.